@@ -54,6 +54,8 @@ from .models import (
     Library,
     LibraryValidator,
     Question,
+    QuestionGrade,
+    QuestionGradeValidator,
     QuestionValidator,
     SelectedQuestion,
     SelectedQuestionValidator,
@@ -268,6 +270,7 @@ async def fetch_last_answer_table_entry(
                 tbl.div_id == query_data.div_id,
                 tbl.course_name == query_data.course,
                 tbl.sid == query_data.sid,
+                tbl.timestamp <= query_data.deadline,
             )
         )
         .order_by(tbl.timestamp.desc())
@@ -876,6 +879,26 @@ async def fetch_assignment_question(
         return AssignmentQuestionValidator.from_orm(res.scalars().first())
 
 
+async def fetch_question_grade(sid: str, course_name: str, qid: str):
+    """
+    Get the grade and any comments for this question
+    """
+    query = (
+        select(QuestionGrade)
+        .where(
+            (QuestionGrade.sid == sid)
+            & (QuestionGrade.course_name == course_name)
+            & (QuestionGrade.div_id == qid)
+        )
+        .order_by(
+            QuestionGrade.id.desc(),
+        )
+    )
+    async with async_session() as session:
+        res = await session.execute(query)
+        return QuestionGradeValidator.from_orm(res.scalars().one_or_none())
+
+
 async def fetch_user_experiment(sid: str, ab_name: str) -> int:
     """
     When a question is part of an AB experiement (ab_name) get the experiment
